AsReadWriteFd

Trait AsReadWriteFd 

pub trait AsReadWriteFd {
    // Required methods
    fn as_read_fd(&self) -> BorrowedFd<'_>;
    fn as_write_fd(&self) -> BorrowedFd<'_>;
}
Like AsFd, but for types which may have one or two file descriptors, for reading and writing.

For types that only have one, both functions return the same value.

Required Methods

fn as_read_fd(&self) -> BorrowedFd<'_>

Extracts the file descriptor for reading.

Like AsFd::as_fd, but returns the reading file descriptor.

fn as_write_fd(&self) -> BorrowedFd<'_>

Extracts the file descriptor for writing.

Like AsFd::as_fd, but returns the writing file descriptor.

Implementations on Foreign Types

Source

impl AsReadWriteFd for File

Available on non-Windows only.
Source

impl AsReadWriteFd for TcpStream

Available on non-Windows only.
Source

impl AsReadWriteFd for UnixStream

Available on Unix only.
Source

impl<T: AsReadWriteFd> AsReadWriteFd for Box<T>

Available on non-Windows only.

Implementors